@@ -1,14 +1,10 @@
 import os
 
-def write_yaml():
-    tests = os.path.join(os.getcwd(), "tests")
+def write_basic_yaml():
     return {
-        "DIRECTORY": tests,
-        "WAVE LENGTHS": [None, None, None, None],
-        "GRADIENTS": [30],
-        "ISOTHERMS": [30, 60, 90],
+        "DIRECTORY": '',
+        "WAVE LENGTHS": [None],
         "RMS": False,
-        "TECHNIQUES": {"STA": True, "IR": True, "GC": False, "MS": True},
     }
 
 def write_yaml():
